@@ -1,5 +1,6 @@
 import sys, os
 import tidyexc
+from tidyexc import Error
 
 ## General
 
@@ -12,6 +13,7 @@ master_doc = 'index'
 source_suffix = '.rst'
 templates_path = ['_templates']
 exclude_patterns = ['_build']
+html_static_path = ['_static']
 default_role = 'any'
 
 ## Extensions
@@ -24,13 +26,13 @@ extensions = [
         'sphinx.ext.intersphinx',
         'sphinx_rtd_theme',
 ]
-intersphinx_mapping = { #
+intersphinx_mapping = {
+        'python': ('https://docs.python.org/3', None),
 }
 autosummary_generate = True
 autodoc_default_options = {
         'exclude-members': '__dict__,__weakref__,__module__',
 }
 html_theme = 'sphinx_rtd_theme'
-html_static_path = ['static']
 pygments_style = 'sphinx'
 
