@@ -90,6 +90,16 @@ Brief
 • Second line
 """
 
+def test_iadd():
+    e = Error()
+
+    e.info += "a"
+    e.info += lambda e: "b"
+    e.info += ["c", "d"]
+    e.info += ("e", "f")
+
+    assert e.info_strs == ["a", "b", "c", "d", "e", "f"]
+
 def test_wrap(monkeypatch):
     import tidyexc.exc, os
     monkeypatch.setattr(
@@ -97,12 +107,16 @@ def test_wrap(monkeypatch):
             lambda: os.terminal_size((10, 1)),
     )
 
-    ruler = "1 3 5 7 9 11 14 17"
+    ruler_breakable = "1 3 5 7 9 11 14 17"
+    ruler_unbreakable = "1-3-5-7-9-11-14-17"
 
-    e = Error(ruler)
-    e.info += ruler
-    e.blame += ruler
-    e.hints += ruler
+    e = Error(ruler_breakable)
+    e.info += ruler_breakable
+    e.info += ruler_unbreakable
+    e.blame += ruler_breakable
+    e.blame += ruler_unbreakable
+    e.hints += ruler_breakable
+    e.hints += ruler_unbreakable
 
     # Caret shows where the wrapping should occur:
     #    v
@@ -112,12 +126,15 @@ def test_wrap(monkeypatch):
 • 1 3 5 7
   9 11 14
   17
+• 1-3-5-7-9-11-14-17
 ✖ 1 3 5 7
   9 11 14
   17
+✖ 1-3-5-7-9-11-14-17
 • 1 3 5 7
   9 11 14
   17
+• 1-3-5-7-9-11-14-17
 """
 
 @pytest.mark.parametrize("s", STRING_TYPES)
